==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Sections/language/lang-portuguese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Imprimir");
define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_COMESFROM","Este artigo veio de");
define("_THEURL","O link deste artigo :");
define("_SECWELCOME","Bem vindo s seces especiais de");
define("_YOUCANFIND","Aqui voc encontrar alguns bons artigos existentes no web site.");
define("_THISISSEC","Esta  a Seco");
define("_FOLLOWINGART","A seguir encontra os artigos publicados.");
define("_SECRETURN","Voltar ao ndice de seces");
define("_TOTALWORDS","total de palavras neste texto");
define("_BACKTO","Voltar");
define("_SECINDEX","ndice de seces");
define("_PAGE","Pginas");

?>

==> phpnuke-6.0.tgz: www/phpnuke/html/modules/Sections/language/lang-portuguese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

/**************************************************************************/
/* Translation by:							  */
/*									  */
/* Rui Cristovo (ord'hor) ordhor@hotmail.com				  */
/**************************************************************************/


define("_PRINTER","Imprimir");
define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Seguinte");
define("_COMESFROM","Este artigo veio de");
define("_THEURL","O link deste artigo :");
define("_SECWELCOME","Bem vindo s seces especiais de");
define("_YOUCANFIND","Aqui voc encontrar alguns bons artigos existentes no web site.");
define("_THISISSEC","Esta  a Seco");
define("_FOLLOWINGART","A seguir encontra os artigos publicados.");
define("_SECRETURN","Voltar ao ndice de seces");
define("_TOTALWORDS","total de palavras neste texto");
define("_BACKTO","Voltar");
define("_SECINDEX","ndice de seces");
define("_PAGE","Pginas");

?>
